from setuptools import setup
from codecs import open
import site

# PEP517
site.ENABLE_USER_SITE = True

exec(open('gtts/version.py').read())

setup(
    version=__version__,   # type: ignore # noqa: F821
    test_suite='gtts.tests',
)



from setuptools import setup

setup(name='simplpython',
      version='0.1',
      description='Easy Python | Python For Everybody',
      packages=['simplpython', 'gtts', 'playsound'],
      author_email='samit.mohnot@gmail.com',
      zip_safe=False)



class simplpython:
    def display(text: str):
        print(text)

    def files_io(filename, mode, text: str):
        if "r" in mode:
            global file_text
            file_text = open(filename, "r").read()
        if "w" in mode:
            open(filename, "w").write(text)

    def TTS(speak: str, language: str, slow_true_or_false: bool):
        from gtts import gTTS
        from playsound import playsound
        import os
        gts = gTTS(text=speak, lang=language, slow=slow_true_or_false)
        gts.save("TTS_TEMP.mp3")
        playsound("TTS_TEMP.mp3")
        if os.path.exists("TTS_TEMP.mp3"):
            os.remove("TTS_TEMP.mp3")
